@@ -7,7 +7,7 @@ package Excel::Writer::XLSX::Workbook;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2014, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2015, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -33,7 +33,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 
 ###############################################################################
@@ -858,6 +858,26 @@ sub add_vba_project {
 }
 
 
+###############################################################################
+#
+# set_vba_name()
+#
+# Set the VBA name for the workbook.
+#
+sub set_vba_name {
+
+    my $self         = shift;
+    my $vba_codemame = shift;
+
+    if ( $vba_codemame ) {
+        $self->{_vba_codename} = $vba_codemame;
+    }
+    else {
+        $self->{_vba_codename} = 'ThisWorkbook';
+    }
+}
+
+
 ###############################################################################
 #
 # set_calc_mode()
@@ -1603,15 +1623,21 @@ sub _prepare_drawings {
         }
     }
 
+
+    # Remove charts that were created but not inserted into worksheets.
+    my @chart_data;
+
+    for my $chart ( @{ $self->{_charts} } ) {
+        if ( $chart->{_id} != -1 ) {
+            push @chart_data, $chart;
+        }
+    }
+
     # Sort the workbook charts references into the order that the were
     # written from the worksheets above.
-    my @chart_data = @{ $self->{_charts} };
-
     @chart_data = sort { $a->{_id} <=> $b->{_id} } @chart_data;
 
     $self->{_charts} = \@chart_data;
-
-
     $self->{_drawing_count} = $drawing_id;
 }
 
@@ -1632,6 +1658,7 @@ sub _prepare_vml_objects {
     my $vml_shape_id   = 1024;
     my $vml_files      = 0;
     my $comment_files  = 0;
+    my $has_button     = 0;
 
     for my $sheet ( @{ $self->{_worksheets} } ) {
 
@@ -1661,6 +1688,17 @@ sub _prepare_vml_objects {
             $sheet->_prepare_header_vml_objects( $vml_header_id,
                 $vml_drawing_id );
         }
+
+        # Set the sheet vba_codename if it has a button and the workbook
+        # has a vbaProject binary.
+        if ( $sheet->{_buttons_array} ) {
+            $has_button = 1;
+
+            if ( $self->{_vba_project} && !$sheet->{_vba_codename} ) {
+                $sheet->set_vba_name();
+            }
+        }
+
     }
 
     $self->{_num_vml_files}     = $vml_files;
@@ -1681,6 +1719,12 @@ sub _prepare_vml_objects {
 
         push @{ $self->{_formats} }, $format;
     }
+
+    # Set the workbook vba_codename if one of the sheets has a button and
+    # the workbook has a vbaProject binary.
+    if ( $has_button && $self->{_vba_project} && !$self->{_vba_codename} ) {
+        $self->set_vba_name();
+    }
 }
 
 
@@ -2534,6 +2578,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-(c) MM-MMXIIII, John McNamara.
+(c) MM-MMXV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
